==> sonnet-5.41.0.tar.xz: sonnet-5.41.0/src/plugins/aspell/aspelldict.h <==
/**
 * kspell_aspelldict.h
 *
 * Copyright (C)  2003  Zack Rusin <zack@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
#ifndef KSPELL_ASPELLDICT_H
#define KSPELL_ASPELLDICT_H

#include "spellerplugin_p.h"

#include "aspell.h"

class ASpellDict : public Sonnet::SpellerPlugin
{
public:
    explicit ASpellDict(const QString &lang);
    ~ASpellDict();
    bool isCorrect(const QString &word) const Q_DECL_OVERRIDE;

    QStringList suggest(const QString &word) const Q_DECL_OVERRIDE;

    bool storeReplacement(const QString &bad,
                                  const QString &good) Q_DECL_OVERRIDE;

    bool addToPersonal(const QString &word) Q_DECL_OVERRIDE;
    bool addToSession(const QString &word) Q_DECL_OVERRIDE;
private:
    AspellConfig  *m_config = nullptr;
    AspellSpeller *m_speller = nullptr;
};

#endif

==> sonnet-5.46.0.tar.xz: sonnet-5.46.0/src/plugins/aspell/aspelldict.h <==
/**
 * kspell_aspelldict.h
 *
 * Copyright (C)  2003  Zack Rusin <zack@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
#ifndef KSPELL_ASPELLDICT_H
#define KSPELL_ASPELLDICT_H

#include "spellerplugin_p.h"

#include "aspell.h"

class ASpellDict : public Sonnet::SpellerPlugin
{
public:
    explicit ASpellDict(const QString &lang);
    ~ASpellDict() Q_DECL_OVERRIDE;
    bool isCorrect(const QString &word) const Q_DECL_OVERRIDE;

    QStringList suggest(const QString &word) const Q_DECL_OVERRIDE;

    bool storeReplacement(const QString &bad, const QString &good) Q_DECL_OVERRIDE;

    bool addToPersonal(const QString &word) Q_DECL_OVERRIDE;
    bool addToSession(const QString &word) Q_DECL_OVERRIDE;
private:
    AspellConfig *m_config = nullptr;
    AspellSpeller *m_speller = nullptr;
};

#endif
